-------------------------------------------------------------------------------
-- remap.vhd
--
-- Created:       Dec 2000
-- Last Modified: Dec 2000
-- 
-- This file only renames signals to names that were in our ucf file at the
-- time.  It is not really required in the design.
-------------------------------------------------------------------------------


library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_unsigned.all;

entity remap is
	port (
		CLK: in STD_LOGIC;
		PB: in STD_LOGIC_VECTOR(1 to 4);
--		DIP: in STD_LOGIC_VECTOR(1 to 7);
		DIP: in STD_LOGIC_VECTOR(1 to 6);
		Lsram_CEn: out STD_LOGIC;
        Rsram_CEn: out STD_LOGIC;
        Lsram_OEn: out STD_LOGIC;
--        Rsram_OEn: out STD_LOGIC;
        Lsram_WEn: out STD_LOGIC;
--        Rsram_WEn: out STD_LOGIC;
        Lsram_Addr: out STD_LOGIC_VECTOR (18 downto 0);
--        Rsram_Addr: out STD_LOGIC_VECTOR (18 downto 0);
        Lsram_Data: inout STD_LOGIC_VECTOR (15 downto 0);
--        Rsram_Data: inout STD_LOGIC_VECTOR (15 downto 0);

 		  RAMDAC_Pixel: out STD_LOGIC_Vector (7 downto 0);
		RAMDAC_Blankn: out STD_LOGIC;
		RAMDAC_RDn: out STD_LOGIC;
		RAMDAC_WRn: out STD_LOGIC;
		  RAMDAC_Data: inout STD_LOGIC_VECTOR (7 downto 0);
		  RAMDAC_RS: inout STD_LOGIC_VECTOR (2 downto 0);
		  RAMDAC_HSync: out STD_LOGIC;
		  RAMDAC_VSync: out STD_LOGIC;
		  RAMDAC_PixelCLK: out STD_LOGIC;

		  Ethernet_TRSTE: out STD_LOGIC;

		Stereo_SDOUT: in STD_LOGIC;
		Stereo_MCLK: out STD_LOGIC;
        Stereo_LRCK: buffer STD_LOGIC;
        Stereo_SCLK: buffer STD_LOGIC;
        Stereo_SDIN: out STD_LOGIC;		

		BAR: out STD_LOGIC_VECTOR(8 to 9)
);
end remap;


architecture rename of remap is

component audiotop
	port (
		clk: in STD_LOGIC;
		rstn: in STD_LOGIC;
		direction: in STD_LOGIC;
		speed: in STD_LOGIC_VECTOR(1 downto 0);	
		precision: in STD_LOGIC;
		volume: in STD_LOGIC_VECTOR(1 downto 0);	
--		panning: in STD_LOGIC;
		CELeftn: out STD_LOGIC;
--        CERightn: out STD_LOGIC;
        OELeftn: out STD_LOGIC;
--        OERightn: out STD_LOGIC;
        WELeftn: out STD_LOGIC;
--        WERightn: out STD_LOGIC;
        SRAMLeftAddr: out STD_LOGIC_VECTOR (18 downto 0);
--        SRAMRightAddr: out STD_LOGIC_VECTOR (18 downto 0);
        SRAMLeftData: inout STD_LOGIC_VECTOR (15 downto 0);
--        SRAMRightData: inout STD_LOGIC_VECTOR (15 downto 0);
		sdout: in STD_LOGIC;
		
		mclk: out STD_LOGIC;
        lrck: buffer STD_LOGIC;
        sclk: buffer STD_LOGIC;
        sdin: out STD_LOGIC;		

		recordStart: in STD_LOGIC;
        playStart: in STD_LOGIC;
        playStop: in STD_LOGIC;
		full: out STD_LOGIC;
				  dataPlay: out STD_LOGIC_VECTOR(31 downto 0);

        done: out STD_LOGIC
);
end component;

component vga
	port(
	clk: in STD_LOGIC;
        rstn: in STD_LOGIC;
		  audioData: in STD_Logic_vector (31 downto 0);
        pixel: out STD_LOGIC_VECTOR (7 downto 0);
        blankn: out STD_LOGIC;
        RDn: out STD_LOGIC;
		WRn: out STD_LOGIC;
		RAMDACD: inout STD_LOGIC_VECTOR (7 downto 0);
		RS: inout STD_LOGIC_VECTOR (2 downto 0);
        hsync: out STD_LOGIC;
        vsync: out STD_LOGIC;
        triste: out STD_LOGIC;
        rramce: out STD_LOGIC;
        pixelclk: out STD_LOGIC
	);
end component;

signal dataPlaying : STD_LOGIC_VECTOR(31 downto 0);
signal main_clk : STD_LOGIC;
--signal rcen_a : STD_LOGIC;
signal rcen_v : STD_LOGIC;
signal reset : STD_LOGIC;

begin
	original : audiotop port map(
		clk => main_clk,
		rstn => reset,
		direction => DIP(1),
		speed => DIP(2 to 3),
		precision => DIP(4),
		volume => DIP(5 to 6),
--		panning => DIP(7),
		
		CELeftn => Lsram_CEn,
--        CERightn => rcen_a,
        OELeftn => Lsram_OEn,
--        OERightn => Rsram_OEn,
        WELeftn => Lsram_WEn,
--        WERightn => Rsram_WEn,
        SRAMLeftAddr => Lsram_Addr,
--        SRAMRightAddr => Rsram_Addr,
        SRAMLeftData => Lsram_Data,
--        SRAMRightData => Rsram_Data,

		sdout => Stereo_SDOUT,
		
		mclk => Stereo_MCLK,
        lrck => Stereo_LRCK,
        sclk => Stereo_SCLK,
        sdin => Stereo_SDIN,

		recordStart => PB(4),
        playStart => PB(3),
        playStop => PB(2),
		full => BAR(8),
		dataPlay => dataPlaying,
        done => BAR(9)
);

-- port map for video
	videomap : vga port map(
		clk => main_clk,
		rstn => reset,
		audioData => dataPlaying,
	  pixel => RAMDAC_Pixel,
   	blankn => RAMDAC_Blankn,
        RDn => RAMDAC_RDn,
		WRn => RAMDAC_WRn,
		RAMDACD => RAMDAC_Data,
		RS => RAMDAC_RS,
        hsync => RAMDAC_HSync,
        vsync => RAMDAC_VSync,
        triste => Ethernet_TRSTE,

        rramce => rcen_v,
        pixelclk => RAMDAC_PixelCLK
);
	main_clk <= CLK;
	reset <= PB(1);
--	Rsram_CEn <= rcen_a or rcen_v;
	Rsram_CEn <= rcen_v;
end rename;
